# OPS10-BP02: Have a process per alert for when it is triggered

## Description

Mỗi alert có response process.

## Implementation Guidance

- Runbook linked to each alert
- Clear ownership per alert
- Response time expectations
- Escalation procedures
- Regular alert review

## Risk Level

Medium - Unclear alert responses cause delays.
